---
title: 포트원 추천패키지는 PG 가입비가 무료!
category: 이벤트
tags:
  - 공통
  - 이벤트
pgCompanies:
  - 스마트로
searchTags:
  - 한국결제네트웍스
  - KPN
  - 제휴혜택
  - 무료
  - 패키지
  - 추천패키지
  - 가입비무료
datetime: 2024-06-28T09:27:52.469Z
---

온라인 결제를 위한 결제수단 연동이 필요하다면, 포트원과 함께 무료로 시작하세요!\
2024\. 7. 1.



복잡하고 머리 아픈 PG사 비교, 분석\
포트원 추천패키지만 믿고 따라오세요.
--------------------

온라인 서비스를 운영하기 위해서 필수적으로 필요한 PG사 가입. 어떤 PG사를 선택해야 할지, 비용은 얼마인지, 결제 형태와 연동방식은 어떻게 되는지. PG 수수료부터 보증보험까지. PG가입을 마음먹었지만 시작부터 많은 선택지 앞에 놓이게 됩니다.

신용카드, 간편결제, 본인인증, 정기결제. 우리 서비스에 필요한 결제수단만 선택하면 최적화된 결제대행사를 선별해 추천해드립니다.

## 포트원 추천패키지는 PG가입비가 0원!

온라인 사업을 시작할 때 초기 많은 비용이 투입되며 부담이 됩니다. PG 가입비 또한 마찬가지인데요. 포트원 추천패키지를 이용하면 22만 원 상당의 PG 가입비를 지원받을 수 있습니다. 내가 원하는 결제수단 선택으로 가장 최적의 결제 대행사를 추천받아 무료로 이용해보세요!



간편결제부터 본인인증까지,\
포트원 추천패키지로 한 번에 연동!
-------------------

신용카드(일반결제/정기결제), 간편 결제, 본인인증. 서비스에 필요한 결제수단을 선택하면 수단별로 가장 적합한 PG사를 추천해드립니다. 포트원 추천패키지를 이용하시면, 결제대행사(PG사) 가입비와 연회비를 무료로 진행할 수 있습니다.



<Callout title="지원 결제 수단" content="신용카드 : 일반결제 / 정기결제
간편결제 : 카카오페이 / 네이버페이 / 페이코 / 토스페이 / 스마일페이
해외결제 : 페이먼트월 / 엑심베이 / 페이팔" icon="💡" />

<Callout content="" title="포트원 추천패키지 보러가기 ↗" />

## 추천패키지 신청 고객사 제공 특별 제휴혜택

포트원 추천패키지를 통해 결제대행사(PG사) 계약을 완료한 고객사에는 AWS 크레디트 제공, Salesfroce(세일즈포스) 특별할인가, 메일링 서비스 Stibee(스티비) 요금제 할인코드 서비스까지 특별 제휴혜택을 제공합니다.

클라우드부터 알림톡 서비스까지 스타트업 운영에 필요한 다양한 혜택까지 포트원과 함께하세요!

<Callout title="포트원 제휴혜택 보러가기 ↗" />

## 단 한 번의 연동으로 결제부터 정산까지 완성

고객과의 접점에서 가장 중요한 ‘결제’ 사업의 성장단계에 따라 결제는 점점 더 중요해집니다. PG 결제부터, 정산 더 나아가 결제데이터 분석까지. 포트원과 함께 결제인프라를 구축해보세요. 국내외 25개 PG사와의 파트너십을 통해 40여 개의 결제수단 연동을 제공하는 포트원이 함께하겠습니다.

